@@ -2,10 +2,12 @@
 
 from ml.ml40.features.functionalities.functionality import Functionality
 
+
 class AcceptsMoveCommands(Functionality):
     """This functionality signalizes that the thing can be moved remotely
     via S3I-B messages ."""
-    def __init__(self, name="", identifier=""):
+
+    def __init__(self, namespace="fml40", name="", identifier="", parent=None):
         """Initializes the object.
 
         :param name:  Object name
@@ -13,8 +15,8 @@ class AcceptsMoveCommands(Functionality):
 
         """
         super().__init__(
-            name=name,
-            identifier=identifier)
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
 
     def move(self, longitude: float, latitude: float):
         """Moves the thing to the position specified longitude and latitude.
