@@ -2,10 +2,8 @@ from ml.ml40.features.properties.values.value import Value
 
 
 class HarvestedVolume(Value):
-    def __init__(self, name="", identifier=""):
-        super().__init__(
-            name=name,
-            identifier=identifier)
+    def __init__(self, namespace="fml40", name="", identifier="", parent=None):
+        super().__init__(namespace=namespace, name=name, identifier=identifier, parent=parent)
 
         self.__volume = None
         self.__json_out = None
