@@ -2,10 +2,10 @@ from ml.ml40.features.properties.values.value import Value
 
 
 class Overhang(Value):
-    def __init__(self, name="", identifier=""):
+    def __init__(self, namespace="fml40", name="", identifier="", parent=None):
         super().__init__(
-            name=name,
-            identifier=identifier)
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
         self.__overhang = None
         self.__json_out = dict()
 
@@ -21,4 +21,4 @@ class Overhang(Value):
         self.__json_out = super().to_json()
         if self.overhang is not None:
             self.__json_out["overhang"] = self.__overhang
-        return self.__json_out
\ No newline at end of file
+        return self.__json_out
