@@ -2,10 +2,10 @@ from ml.ml40.features.properties.associations.association import Association
 
 
 class Shared(Association):
-    def __init__(self, name="", identifier=""):
-        super(Shared, self).__init__(
-            name=name,
-            identifier=identifier)
+    def __init__(self, namespace="ml40", name="", identifier="", parent=None):
+        super().__init__(
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
         self.__targets = []
         self.__targets = dict()
         self.__json_out = dict()
@@ -22,6 +22,6 @@ class Shared(Association):
         self.__json_out = super().to_json()
         if self.targets:
             self.__json_out["targets"] = []
-            for key in self.targets.keys():
-                self.__json_out["targets"].append(self.targets[key].to_subthing_json())
+            for key in self.__targets.keys():
+                self.__json_out["targets"].append(self.targets[key].entry.refresh_sub_thing_repo_entry())
         return self.__json_out
