@@ -2,14 +2,13 @@ from ml.ml40.features.properties.values.documents.jobs.job import Job
 
 
 class GenericJob(Job):
-    def __init__(self, name="", identifier=""):
+    def __init__(self, namespace="ml40", name="", identifier="", parent=None):
         super().__init__(
-            name=name,
-            identifier=identifier)
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
         self.__content = None
         self.__json_out = dict()
 
-
     @property
     def content(self):
         return self.__content
