@@ -2,14 +2,14 @@ from ml.ml40.features.properties.values.value import Value
 
 
 class Location(Value):
-    def __init__(self, name="", identifier=""):
+    def __init__(self, namespace="ml40", name="", identifier="", parent=None):
         super().__init__(
-            name=name,
-            identifier=identifier)
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
         self.__latitude = None
         self.__longitude = None
         self.__orientation = None
-        self.__json_out = dict()
+        self.__json_out = {}
 
     @property
     def latitude(self):
@@ -43,5 +43,4 @@ class Location(Value):
             self.__json_out["longitude"] = self.longitude
         if self.orientation is not None:
             self.__json_out["orientation"] = self.orientation
-
-        return self.__json_out
\ No newline at end of file
+        return self.__json_out
