@@ -2,10 +2,10 @@ from ml.ml40.features.properties.values.value import Value
 
 
 class Temperature(Value):
-    def __init__(self, name="", identifier=""):
+    def __init__(self, namespace="ml40", name="", identifier="", parent=None):
         super().__init__(
-            name=name,
-            identifier=identifier)
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
         self.__temperature = None
         self.__json_out = dict()
 
@@ -25,7 +25,3 @@ class Temperature(Value):
         if self.temperature is not None:
             self.__json_out["temperature"] = self.temperature
         return self.__json_out
-
-
-
-
