@@ -1,14 +1,14 @@
 import asyncio
-import threading
-import time
 
+import s3i
 from s3i.identity_provider import IdentityProvider, TokenType
 from s3i.directory import Directory
 from s3i.repository import Repository
 # from s3i.broker import BrokerREST, Broker
 from s3i.event_system import EventManager
 from ml.s3i_tools import Broker, BrokerREST
-from s3i.messages import GetValueReply, ServiceReply, SetValueReply, CustomEventReply
+from s3i.broker_message import GetValueReply, ServiceReply, SetValueReply, CustomEventReply, GetValueRequest, \
+    ServiceRequest, SetValueRequest
 from s3i.exception import raise_error_from_s3ib_msg, S3IBMessageError, S3IDittoError, S3IIdentityProviderError
 from ml.app_logger import APP_LOGGER
 from ml.tools import find_broker_endpoint
@@ -76,43 +76,47 @@ class Thing:
             APP_LOGGER.info("[S3I]: Disconnect from S3I")
             self.loop.close()
 
-    def add_on_thing_start_ok_callback(self, callback_func, one_shot, *args, **kwargs):
+    def add_on_thing_start_ok_callback(self, callback_func, one_shot, is_async, *args, **kwargs):
         self.callbacks.add(
             self._ON_THING_START_OK,
             callback_func,
             one_shot,
+            is_async,
             *args,
             **kwargs
         )
 
-    def add_on_idp_start_ok_callback(self, callback_func, one_shot, *args, **kwargs):
+    def add_on_idp_start_ok_callback(self, callback_func, one_shot, is_async, *args, **kwargs):
         self.callbacks.add(
             self._ON_IDP_START_OK,
             callback_func,
             one_shot,
+            is_async,
             *args,
             **kwargs
         )
 
-    def add_on_directory_start_ok_callback(self, callback_func, one_shot, *args, **kwargs):
+    def add_on_directory_start_ok_callback(self, callback_func, one_shot, is_async, *args, **kwargs):
         self.callbacks.add(
             self._ON_DIRECTORY_START_OK,
             callback_func,
             one_shot,
+            is_async,
             *args,
             **kwargs
         )
 
-    def add_on_repository_start_ok_callback(self, callback_func, one_shot, *args, **kwargs):
+    def add_on_repository_start_ok_callback(self, callback_func, one_shot, is_async, *args, **kwargs):
         self.callbacks.add(
             self._ON_REPOSITORY_START_OK,
             callback_func,
             one_shot,
+            is_async,
             *args,
             **kwargs
         )
 
-    def add_on_broker_start_ok_callback(self, callback_func, one_shot, *args, **kwargs):
+    def add_on_broker_start_ok_callback(self, callback_func, one_shot, is_async, *args, **kwargs):
         def _add_on_channel_open_callback(_thing, _callback, _one_shot, *_args, **_kwargs):
             _thing.broker.add_on_channel_open_callback(
                 callback_func,
@@ -124,6 +128,7 @@ class Thing:
             self._ON_BROKER_START_OK,
             _add_on_channel_open_callback,
             one_shot,
+            is_async, # the following parameters are *args
             self,
             callback_func,
             one_shot,
@@ -132,7 +137,7 @@ class Thing:
         )
 
     def add_ml40_implementation(self, implementation_object, ml40_feature, *args, **kwargs):
-        async def _add_ml40_implementation(_thing, _implementation_object, _ml40_feature, *_args, **_kwargs):
+        def _add_ml40_implementation(_thing, _implementation_object, _ml40_feature, *_args, **_kwargs):
             feature = _thing.entry.features.get(_ml40_feature, None)
             if feature is None:
                 APP_LOGGER.critical(
@@ -147,6 +152,7 @@ class Thing:
         self.add_on_thing_start_ok_callback(
             _add_ml40_implementation,
             True,
+            False,
             self,
             implementation_object,
             ml40_feature,
@@ -183,7 +189,7 @@ class Thing:
             APP_LOGGER.info("[S3I]: Access Token granted")
         self.loop.call_later(self.__get_remaining_time_to_refresh(),
                              self.__refresh_token_recur)
-        self.callbacks.process_async_task(
+        self.callbacks.process(
             self._ON_IDP_START_OK,
             self.loop
         )
@@ -217,7 +223,7 @@ class Thing:
     def __setup_thing_json_sync(self):
         APP_LOGGER.info("[S3I]: Start the thing")
         self.__recursively_update_dt_json(frequency=self.parameters.thing_sync_freq)
-        self.callbacks.process_async_task(
+        self.callbacks.process(
             prefix=self._ON_THING_START_OK,
             loop=self.loop
         )
@@ -229,7 +235,7 @@ class Thing:
             token=self.__token
         )
         self.__recursively_update_directory(frequency=self.parameters.dir_sync_freq)
-        self.callbacks.process_async_task(
+        self.callbacks.process(
             self._ON_DIRECTORY_START_OK,
             self.loop
         )
@@ -252,6 +258,7 @@ class Thing:
             self.broker.connect()
         self.callbacks.process(
             self._ON_BROKER_START_OK,
+            self.loop
             )
 
     def __setup_repository(self):
@@ -261,7 +268,7 @@ class Thing:
             token=self.__token
         )
         self.__recursively_update_repository(frequency=self.parameters.repo_sync_freq)
-        self.callbacks.process_async_task(
+        self.callbacks.process(
             self._ON_REPOSITORY_START_OK,
             self.loop
         )
@@ -340,7 +347,6 @@ class Thing:
                 self.on_user_message(body)
             elif message_type == "serviceRequest":
                 self.loop.create_task(self.on_service_request(body))
-                #self.on_service_request(body)
             elif message_type == "getValueRequest":
                 self.on_get_value_request(body)
             elif message_type == "setValueRequest":
@@ -365,12 +371,13 @@ class Thing:
         :param msg: GetValueRequest
 
         """
-        get_value_reply = GetValueReply()
-        request_sender = msg.get("sender")
-        request_msg_id = msg.get("identifier")
-        request_sender_endpoint = msg.get("replyToEndpoint")
-        attribute_path = msg.get("attributePath")
+        req = GetValueRequest(base_msg=msg)
+        request_sender = req.base_msg.get("sender")
+        request_msg_id = req.base_msg.get("identifier")
+        request_sender_endpoint = req.base_msg.get("replyToEndpoint")
+        attribute_path = req.base_msg.get("attributePath")
         reply_msg_uuid = "s3i:" + str(uuid.uuid4())
+
         try:
             __log = "[S3I]: Search the given attribute path: {}".format(attribute_path)
             APP_LOGGER.info(__log)
@@ -380,17 +387,18 @@ class Thing:
             __log = "[S3I]: " + value
             APP_LOGGER.critical(__log)
 
+        get_value_reply = GetValueReply()
         get_value_reply.fillGetValueReply(
-            senderUUID=self.identifier,
-            receiverUUIDs=[request_sender],
-            results=value,
-            msgUUID=reply_msg_uuid,
-            replyingToUUID=request_msg_id,
+            sender=self.identifier,
+            receivers=[request_sender],
+            message_id=reply_msg_uuid,
+            replying_to_msg=request_msg_id,
+            value=value
         )
 
         res = self.broker.send(
             endpoint=request_sender_endpoint,
-            msg=get_value_reply.msg
+            msg=get_value_reply.base_msg
         )
         if res:
             APP_LOGGER.info("[S3I]: Sending getValueReply back")
@@ -519,8 +527,12 @@ class Thing:
         :param body_json: ServiceRequest
 
         """
-        service_type = body_json.get("serviceType")
-        parameters = body_json.get("parameters")
+        req = ServiceRequest(base_msg=body_json)
+        service_type = req.base_msg.get("serviceType")
+        parameters = req.base_msg.get("parameters")
+        request_sender = req.base_msg.get("sender")
+        request_id = req.base_msg.get("identifier")
+
         service_reply = ServiceReply()
         service_functionality = service_type.split('/')[0]
         service_functionality_obj = self.entry.features.get(service_functionality)
@@ -530,12 +542,12 @@ class Thing:
                 % (service_functionality, self.entry.name)
             )
             service_reply.fillServiceReply(
-                senderUUID=self.identifier,
-                receiverUUIDs=[body_json.get("sender", None)],
-                serviceType=body_json.get("serviceType", None),
+                sender=self.identifier,
+                receivers=[request_sender],
+                service_type=service_type,
                 results={"error": "invalid functionalities (serviceType) {}".format(service_functionality)},
-                replyingToUUID=body_json.get("identifier", None),
-                msgUUID="s3i:{}".format(uuid.uuid4())
+                replying_to_msg=request_id,
+                message_id="s3i:{}".format(uuid.uuid4())
             )
         else:
             # TODO: Call right functionality.
@@ -547,24 +559,24 @@ class Thing:
                         service_type.split('/')[1], self.entry.name)
                 )
                 service_reply.fillServiceReply(
-                    senderUUID=self.identifier,
-                    receiverUUIDs=[body_json.get("sender", None)],
-                    serviceType=body_json.get("serviceType", None),
+                    sender=self.identifier,
+                    receivers=[request_sender],
+                    service_type=service_type,
+                    replying_to_msg=request_id,
+                    message_id="s3i:{}".format(uuid.uuid4()),
                     results={"error": "invalid method {}".format(service_type.split('/')[1])},
-                    replyingToUUID=body_json.get("identifier", None),
-                    msgUUID="s3i:{}".format(uuid.uuid4())
                 )
             except IndexError:
                 APP_LOGGER.critical(
                     "[S3I]: ServiceType consists of functionality and method name."
                 )
                 service_reply.fillServiceReply(
-                    senderUUID=self.identifier,
-                    receiverUUIDs=[body_json.get("sender", None)],
-                    serviceType=body_json.get("serviceType", None),
+                    sender=self.identifier,
+                    receivers=[request_sender],
+                    service_type=service_type,
+                    replying_to_msg=request_id,
                     results={"error": "method missing"},
-                    replyingToUUID=body_json.get("identifier", None),
-                    msgUUID="s3i:{}".format(uuid.uuid4())
+                    message_id="s3i:{}".format(uuid.uuid4())
                 )
             else:
                 __log = "[S3I]: Execute the function {0} of the class {1}".format(service_type.split('/')[1],
@@ -572,16 +584,15 @@ class Thing:
                 APP_LOGGER.info(__log)
                 try:
                     result = await method(**parameters)
-                    #result = method(**parameters)
                 except TypeError:
                     APP_LOGGER.critical("[S3I]: Invalid function arguments")
                     service_reply.fillServiceReply(
-                        senderUUID=self.identifier,
-                        receiverUUIDs=[body_json.get("sender", None)],
-                        serviceType=body_json.get("serviceType", None),
+                        sender=self.identifier,
+                        receivers=[request_sender],
+                        service_type=service_type,
+                        replying_to_msg=request_id,
                         results={"error": "invalid function arguments (parameters)"},
-                        replyingToUUID=body_json.get("identifier", None),
-                        msgUUID="s3i:{}".format(uuid.uuid4())
+                        message_id="s3i:{}".format(uuid.uuid4())
                     )
                 else:
                     if isinstance(result, bool):
@@ -589,17 +600,17 @@ class Thing:
                     elif result is None:
                         result = "None"
                     service_reply.fillServiceReply(
-                        senderUUID=self.identifier,
-                        receiverUUIDs=[body_json.get("sender", None)],
-                        serviceType=body_json.get("serviceType", None),
+                        sender=self.identifier,
+                        receivers=[request_sender],
+                        service_type=service_type,
+                        replying_to_msg=request_id,
                         results=result,
-                        replyingToUUID=body_json.get("identifier", None),
-                        msgUUID="s3i:{}".format(uuid.uuid4())
+                        message_id="s3i:{}".format(uuid.uuid4())
                     )
 
         res = self.broker.send(
             endpoint=body_json.get("replyToEndpoint", None),
-            msg=service_reply.msg)
+            msg=service_reply.base_msg)
 
         if res:
             APP_LOGGER.info("[S3I]: Sending serviceReply back")
@@ -613,11 +624,14 @@ class Thing:
 
         """
         set_value_reply = SetValueReply()
-        request_sender = msg.get("sender")
-        request_msg_id = msg.get("identifier")
-        request_sender_endpoint = msg.get("replyToEndpoint")
-        attribute_path = msg.get("attributePath")
-        new_value = msg.get("newValue")
+
+        req = SetValueRequest(base_msg=msg)
+
+        request_sender = req.base_msg.get("sender")
+        request_msg_id = req.base_msg.get("identifier")
+        request_sender_endpoint = req.base_msg.get("replyToEndpoint")
+        attribute_path = req.base_msg.get("attributePath")
+        new_value = req.base_msg.get("newValue")
         reply_msg_uuid = "s3i:" + str(uuid.uuid4())
 
         try:
@@ -634,15 +648,15 @@ class Thing:
             result = False
 
         set_value_reply.fillSetValueReply(
-            senderUUID=self.identifier,
-            receiverUUIDs=[request_sender],
+            sender=self.identifier,
+            receivers=[request_sender],
             ok=result,
-            replyingToUUID=request_msg_id,
-            msgUUID=reply_msg_uuid
+            replying_to_msg=request_msg_id,
+            message_id=reply_msg_uuid
         )
         res = self.broker.send(
             endpoint=request_sender_endpoint,
-            msg=set_value_reply.msg
+            msg=set_value_reply.base_msg
         )
         if res:
             APP_LOGGER.info("[S3I]: Sending setValueReply back")
@@ -723,12 +737,12 @@ class Thing:
             receivers=[msg.get("sender")],
             topic=topic,
             replying_to_msg=msg.get("identifier"),
-            msg_id="s3i:" + str(uuid.uuid4()),
+            message_id="s3i:" + str(uuid.uuid4()),
             status="ok" if subscription_status else "invalid request"
         )
         res = self.broker.send(
             msg.get("replyToEndpoint"),
-            msg=event_sub_reply.msg
+            msg=event_sub_reply.base_msg
         )
         if res:
             APP_LOGGER.info("[S3I]: Sending customEventReply back")
